<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>HomeDaemon</name>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="71"/>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="83"/>
        <source>Show main window</source>
        <translation>Pokaż okno główne</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="89"/>
        <source>Communication</source>
        <translation>Komunikacja</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="92"/>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../src/main/homeDaemon.cpp" line="333"/>
        <source>View</source>
        <translation>Widok</translation>
    </message>
</context>
</TS>